@@ -25,6 +25,10 @@ def get_native_version():
     return quikklycore.check_linking()
 
 
+def get_template_info():
+    return quikklycore.get_template_info()
+
+
 def generate_svg(type, data,
                  border_color=None, background_color=None,
                  mask_color=None, overlay_color=None, data_colors=None,
